@@ -1,6 +1,6 @@
 from sockpuppet.reflex import Reflex
 
 
-class {{ reflex_name|title }}Reflex(Reflex):
+class {{ class_name }}Reflex(Reflex):
     def increment(self, step=1):
         self.count = int(self.element.dataset['count']) + step
